@@ -15,11 +15,14 @@ def Apps(args,apps,parser):
 def Env(args,apps,parser):
     if args.app:
         if args.app in apps:
-            stream = os.popen(f"xovnoc env -a {args.app}")
-            envs = str(stream.read()).strip().split('\n')
-            for envvar in envs:
-                print(f'{envvar}')
-            # print(args.app)
+            if args.set:
+                stream = os.system(f"xovnoc env set {' '.join([ vars for vars in args.set])} -a {args.app}")
+            else:
+                stream = os.popen(f"xovnoc env -a {args.app}")
+                envs = str(stream.read()).strip().split('\n')
+                for envvar in envs:
+                    print(f'{envvar}')
+                # print(args.app)
         else:
             print("Wrong Application Name!!..\nPlease provide application name from the below")
             for index,appname in enumerate(apps):
@@ -29,27 +32,27 @@ def Env(args,apps,parser):
     else:
         print('Please specify the application name using --app / -a <application_name>')
 
-def SetEnv(args,apps,parser):
-    if args.app:
-        if args.app in apps:
-            option=''
-            while option not in 'Y,y,N,n'.split(','):
-                option=str(input("Would you like pyconvox to promote the new release? (Y/N): ")).strip()
-                if option == 'Y' or option == 'y':
-                    stream = os.system(f"xovnoc env set {' '.join([ vars for vars in args.envvars])} -a {args.app} -p -w")
-                elif option == 'N' or option == 'n':
-                    stream = os.system(f"xovnoc env set {' '.join([ vars for vars in args.envvars])} -a {args.app}")
-                else:
-                    print("Only Y or N accepted!")
-            # print(args.app)
-        else:
-            print("Wrong Application Name!!..\nPlease provide application name from the below")
-            for index,appname in enumerate(apps):
-                print(f"{index+1}. {appname}")
-            print()
-            parser.print_help()
-    else:
-        print('Please specify the application name using --app / -a <application_name>')
+# def SetEnv(args,apps,parser):
+#     if args.app:
+#         if args.app in apps:
+#             option=''
+#             while option not in 'Y,y,N,n'.split(','):
+#                 option=str(input("Would you like pyconvox to promote the new release? (Y/N): ")).strip()
+#                 if option == 'Y' or option == 'y':
+#                     stream = os.system(f"xovnoc env set {' '.join([ vars for vars in args.envvars])} -a {args.app} -p -w")
+#                 elif option == 'N' or option == 'n':
+#                     stream = os.system(f"xovnoc env set {' '.join([ vars for vars in args.envvars])} -a {args.app}")
+#                 else:
+#                     print("Only Y or N accepted!")
+#             # print(args.app)
+#         else:
+#             print("Wrong Application Name!!..\nPlease provide application name from the below")
+#             for index,appname in enumerate(apps):
+#                 print(f"{index+1}. {appname}")
+#             print()
+#             parser.print_help()
+#     else:
+#         print('Please specify the application name using --app / -a <application_name>')
 
 
 def Scale(args,apps,parser):
@@ -136,20 +139,20 @@ def main():
     parser.add_argument("--version","-V",action="version",version=f"%(prog)s version {pyconvox.__version__}",
     )
     subparsers = parser.add_subparsers(help='Commands')
-    parser_0 = subparsers.add_parser('envset', help='set env var')
-    parser_0.add_argument('--app', '-a', help='application name')
-    parser_0.add_argument('envvars', metavar='Key=Value', nargs='+',help='env var(s) Key1=Value1,Key2=Value2,...')
-    parser_0.set_defaults(which='envset')
+    # parser_0 = subparsers.add_parser('envset', help='set env var')
+    # parser_0.add_argument('--app', '-a', help='application name')
+    # parser_0.add_argument('envvars', metavar='Key=Value', nargs='+',help='env var(s) Key1=Value1,Key2=Value2,...')
+    # parser_0.set_defaults(which='envset')
 
-    parser_a = subparsers.add_parser('env', help='list env vars')
-    parser_a.add_argument('set', help='set environment variables KEY=VALUE')
+    parser_a = subparsers.add_parser('env', help='list/set env vars')
+    parser_a.add_argument('set', metavar='set', nargs='*', help='set environment variables KEY=VALUE')
     parser_a.add_argument('--app', '-a', help='application name')
     parser_a.set_defaults(which='env')
 
-    parser_b = subparsers.add_parser('railsc', help='run rails c')
+    parser_b = subparsers.add_parser('railsconsole', help='run rails console')
     parser_b.add_argument('--app', '-a', help='application name')
     parser_b.add_argument('--service', '-s', help='Service name')
-    parser_b.set_defaults(which='railsc')
+    parser_b.set_defaults(which='railsconsole')
     parser_b.set_defaults(service='')
 
     parser_c = subparsers.add_parser('scale', help='scale of a application')
@@ -182,12 +185,12 @@ def main():
     if hasattr(args, 'which'):
         if args.which == 'env':
             Env(args,apps,parser)
-        elif args.which == 'railsc':
+        elif args.which == 'railsconsole':
             RailsC(args,apps,parser)
         elif args.which == 'scale':
             Scale(args,apps,parser)
-        elif args.which == 'envset':
-            SetEnv(args,apps,parser)
+        # elif args.which == 'envset':
+        #     SetEnv(args,apps,parser)
         elif args.which == 'logs':
             Logs(args,apps,parser)
         elif args.which == 'instances':
